@@ -18,7 +18,7 @@
 #' @noRd
 #' @keywords internal
 .charlson <- function(id.vars, iddf, cmrb, primarydx.var, method) {
-  ccc <- unique(mdcr_select(cmrb, cols = c(id.vars, "condition", primarydx.var)))
+  ccc <- mdcr_unique(mdcr_select(cmrb, cols = c(id.vars, "condition", primarydx.var)))
 
   # omit primary dx
   idx <- which(ccc[[primarydx.var]] == 0L)
@@ -62,7 +62,7 @@
   cci      <- as.integer(as.vector(X %*% cci_wt))
 
   # build the return object
-  rtn <- cbind(iddf, as.data.frame(X, check.names = FALSE, stringsAsFactors = FALSE))
+  rtn <- mdcr_cbind(iddf, as.data.frame(X, check.names = FALSE, stringsAsFactors = FALSE))
   rtn <- mdcr_set(rtn, j = "num_cmrb",  value = num_cmrb)
   rtn <- mdcr_set(rtn, j = "cmrb_flag", value = cmrb_flag)
   rtn <- mdcr_set(rtn, j = "cci",      value = cci)
